import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import AccountInformation from "@/components/sections/user-account/account-informtion";
import PurchaseTable from "@/components/sections/user-account/purchase-table";
import UserAccountHeader from "@/components/sections/user-account/user-account-header";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import LocomotiveScrollWrapper from "@/components/ui/locomotive-scroll-wrapper";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { fetchOrders } from "@/servers/actions/order-action";
import { LocaleParams } from "@/types/params";
import { HydrationBoundary, dehydrate } from "@tanstack/react-query";

export default async function UserAccount({ params }: { params: LocaleParams }) {
	const { locale } = await params;

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/user-account",
			label: {
				en: "User Account",
				ar: "حساب المستخدم",
			},
		},
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
		queryClient.prefetchQuery({ queryKey: ["orders", "paginated", 1, 10], queryFn: () => fetchOrders(1, 10) }),
	]);

	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<LocomotiveScrollWrapper>
				<main className="block">
					<Header />
					<PageBreadcrump
						locale={locale}
						subtitle={{
							en: "Bin Taleb Company",
							ar: "شركة بن طالب",
						}}
						title={{
							en: "User Account",
							ar: "حساب المستخدم",
						}}
						breadcrumbItems={breadcrumbItems}
					/>
					<div className="px-2 sm:px-2 md:px-4 lg:px-4 xl:px-24">
						<div className="relative mx-2 mb-3 mt-6 max-w-10xl overflow-hidden rounded-lg p-4 shadow-lg md:mx-auto md:mb-8 md:mt-12 md:p-8">
							<UserAccountHeader />
							<AccountInformation accountForm={false} />
							<div className="absolute left-0 top-0 z-0 h-16 w-full bg-gradient-blue md:h-24" />
							<PurchaseTable />
						</div>
					</div>
					<Footer />
				</main>
			</LocomotiveScrollWrapper>
		</HydrationBoundary>
	);
}
